from flask import Flask
from flask.ext.sqlalchemy import SQLAlchemy
from flask.ext.login import LoginManager
import logging
import os

logging.basicConfig(level=logging.INFO,
                    format='[%(asctime)s] [%(name)s] [%(levelname)s] %(message)s',
                    datefmt='%Y%m%d-%H:%M%p')

# Flask App
app = Flask(__name__)


# load default configuration
if os.getenv('DEV') == 'true':
    app.config.from_object('blockerbugs.config.DevelopmentConfig')
elif os.getenv('TEST') == 'true':
    app.config.from_object('blockerbugs.config.TestingConfig')
else:
    app.config.from_object('blockerbugs.config.ProductionConfig')


# load real configuration values to override defaults
config_file = '/etc/blockerbugs/settings.py'
if os.path.exists(config_file):
    app.logger.info('Loading configuration from %s' % config_file)
    app.config.from_pyfile(config_file)
else:
    config_file = os.path.abspath('conf/settings.py')
    if os.path.exists(config_file):
        app.logger.info('Loading configuration from %s' % config_file)
        app.config.from_pyfile(config_file)
    else:
        app.logger.info('No extra config found, using defaults')


# setup logging
if app.debug:
    logging.basicConfig(level=logging.DEBUG,
                       format='[%(asctime)s] [%(name)s] [%(levelname)s] %(message)s',
                       datefmt='%Y%m%d-%H:%M%p')


app.logger.debug('using DBURI: %s' % app.config['SQLALCHEMY_DATABASE_URI'])

# database 
db = SQLAlchemy(app)

# setup login manager
login_manager = LoginManager()
login_manager.setup_app(app)
login_manager.login_view = 'admin.login'


@app.template_filter('tagify')
def tagify(value):
    return value.replace(' ', '')

# register blueprints
from blockerbugs.controllers.main import main
app.register_blueprint(main)

from blockerbugs.controllers.admin import admin
app.register_blueprint(admin)
