#
# initialize.py - utilities for setting up the blockerbugs tracker
#
# Copyright 2012, Red Hat, Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# Authors:
#   Tim Flink <tflink@redhat.com>


from optparse import OptionParser
import os
import sys

def initialize_db():
    from blockerbugs import db

    print "Initializing Database"
    db.drop_all()
    db.create_all()

def add_user(username, password):
    from blockerbugs import db
    from blockerbugs.models.user import User

    print "Adding user %s" % username
    admin_user = User(username, password)
    db.session.add(admin_user)
    db.session.commit()

def add_release(number, release, blocker, nth):
    from blockerbugs import db
    from blockerbugs.models.release import Release

    print "Adding release: %s-%s (%s, %s)" % (number, release, blocker, nth)

    current_releases = Release.query.filter_by(active=True).count()
    release_num = int(number)
    new_release = Release(release_num, release, int(blocker), int(nth),
                                            '%d-%s' % (release_num, release))

    # only active releases are synced but since this release is being added,
    # it's a good assumption to make it active.
    new_release.active = True

    # there should be only one current release, the new release as current if
    # there are no current releases defined
    if current_releases <= 0:
        new_release.current = True
    db.session.add(new_release)
    db.session.commit()


def generate_config(dburi=None):
    config_filename = os.path.abspath('conf/settings.py')
    if os.path.exists(config_filename):
        print "configuration file %s already exists, exiting" % config_filename
        sys.exit(0)

    secret_key = os.urandom(24).encode('string_escape')

    config_file = open(config_filename, 'w')
    config_file.write('SECRET_KEY = \'%s\'\n' % secret_key)
    if dburi:
        config_file.write('SQLALCHEMY_DATABASE_URI = ')
        config_file.write('\'%s\'\n' % dburi)
    config_file.close()

if __name__ == '__main__':
    usage = 'usage: %prog [options] command'
    parser = OptionParser(usage=usage)
    parser.add_option('-d', '--dburi', dest='dburi',help='dburi to use')
    parser.add_option('-u', '--user', dest='user', default='admin',
                            help='user to add to db')
    parser.add_option('-p', '--password', default='adminadminadmin',
                            dest='password', help='user to add to db')
    parser.add_option('-n' ,'--number', dest='number', help='release number to add')
    parser.add_option('-r', '--release', dest='release', help='release version to add')
    parser.add_option('-b', '--blocker', dest='blocker', help='blocker tracking bug id')
    parser.add_option('-a', '--accepted', dest='nth', help='NTH tracking bug id')

    (options, args) = parser.parse_args()

    if len(args) < 1:
        print "need to have at least 1 command"
        sys.exit(1)

    possible_commands = ['init_db', 'config_file', 'add_user', 'add_release']
    command = args[0]
    if not command in possible_commands:
        print 'Invalid command: %s' % command
        print 'Please use one of the following commands: %s' % str(possible_commands)
        sys.exit(1)

    if command == 'init_db':
        initialize_db()
        sys.exit(0)
    if command == 'config_file':
        generate_config(dburi = options.dburi)
    if command == 'add_user':
        add_user(options.user, options.password)
    if command == 'add_release':
        add_release(options.number, options.release, options.blocker, options.nth)
