#
# sync_db.py - simple script to sync the db with rhbz
#
# Copyright 2012, Red Hat, Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# Authors:
#   Tim Flink <tflink@redhat.com>


from blockerbugs.models.release import Release
from blockerbugs.util.bug_sync import BugSync
from blockerbugs import db
import logging
import sys

from blockerbugs.util.bz_interface import BlockerBugs
from blockerbugs.models.bug import Bug

logging.basicConfig(level=logging.INFO,
                   format='[%(asctime)s] [%(name)s] [%(levelname)s] %(message)s',
                   datefmt='%Y%m%d-%H:%M%p')

def check_blockers():
    bzinterface = BlockerBugs()
    active_releases = Release.query.filter_by(active=True).all()
    for release in active_releases:
        missing_bugs = []
        buglist = bzinterface.do_query(release.blocker_tracker)
        for bug in buglist:
            bugid = bug.bug_id
            new_bug = Bug.query.filter_by(bugid=bugid).first()
            if not new_bug:
                missing_bugs.append(bugid)

        print "========================================"
        print "Fedora %d %s Missing Blocker Bugs" % (release.number, release.version)
        print "========================================"
        if len(missing_bugs) > 0:
            for bug in missing_bugs:
                print "  * %d" % bug
        else:
            print "  No missing bugs found"



if __name__ == '__main__':
    sync = BugSync(db)

    current_release = Release.query.filter_by(active=True).first()
    if not current_release:
        sys.stderr.write('BugSync ERROR: No active releases found!')
        sys.exit(1)

    last_updated = current_release.last_updated

    sync.update_active(last_updated)

    print "Checking sync status"
    check_blockers()
