from blockerbugs.models.release import Release
from blockerbugs.models.bug import Bug
from blockerbugs import db

def generate_release(version, name, blocker_tracker=123456, accepted_tracker=234567):
    return Release(99, version, blocker_tracker, accepted_tracker, name)

def generate_bug(bugid, summary, release):
    return Bug(bugid, 'https://bugzilla.redhat.com/show_bug.cgi?id=%d' % bugid,
                summary, 'NEW', 'testcomponent', release, True)

class TestfuncBugModel(object):
    def setup_method(self, method):
        db.drop_all()
        db.create_all()

    def test_add_release(self):
        ref_version = 'alpha'
        ref_name = '99-alpha'

        testrelease = generate_release(ref_version, ref_name)
        db.session.add(testrelease)
        db.session.commit()

        releases = Release.query.filter_by(name=ref_name).all()
        assert len(releases) == 1
        release = releases[0]
        assert release.version == ref_version
        assert release.name == ref_name

    def test_add_bug(self):
        ref_release = generate_release('alpha', '99-alpha')
        db.session.add(ref_release)
        db.session.commit()

        ref_bugid = 123456
        ref_summary = 'testbug 1'
        testbug = generate_bug(ref_bugid, ref_summary, ref_release)

        db.session.add(testbug)
        db.session.commit()

        bugs = Bug.query.filter_by(bugid=ref_bugid).all()
        assert len(bugs) == 1
        bug = bugs[0]
        assert bug.bugid == ref_bugid
        assert bug.summary == ref_summary
        assert bug.release == ref_release

    # no longer supporting bugs in multiple releases, invalid tests
#    def test_add_bug_multiple_releases(self):
#        ref_release1 = generate_release('alpha', '99-alpha')
#        ref_release2 = generate_release('beta', '99-beta', blocker_tracker=345678, accepted_tracker=456789)
#        db.session.add(ref_release1)
#        db.session.add(ref_release2)
#        db.session.commit()
#
#        ref_bugid = 123456
#        testbug = generate_bug(ref_bugid, 'testbug1', ref_release1)
#        testbug.releases.append(ref_release2)
#        db.session.add(testbug)
#        db.session.commit()
#
#        bug = Bug.query.filter_by(bugid=ref_bugid).first()
#        assert ref_release1 in bug.releases
#        assert ref_release2 in bug.releases
#
#    def test_bug_in_multiple_releases(self):
#        ref_release1 = generate_release('alpha', '99-alpha')
#        ref_release2 = generate_release('beta', '99-beta', blocker_tracker=345678, accepted_tracker=456789)
#        db.session.add(ref_release1)
#        db.session.add(ref_release2)
#        db.session.commit()
#
#        ref_bugid = 123456
#        testbug = generate_bug(ref_bugid, 'testbug1', ref_release1)
#        testbug.releases.append(ref_release2)
#        db.session.add(testbug)
#        db.session.commit()
#
#        release1 = Release.query.filter_by(name=ref_release1.name).first()
#        assert testbug in release1.bugs
#
#        release2 = Release.query.filter_by(name=ref_release2.name).first()
#        assert testbug in release2.bugs
